@@ -6,7 +6,7 @@ use v5.20;
 
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Hash::Fold 'unfold';
 use List::Util   qw( first );
@@ -133,7 +133,7 @@ sub _create_options (
 
             push @optargs,
               $is_subform
-              ? get_package_form_meta( blessed $def->type )->_create_options( $rename, @paths )
+              ? get_package_form_meta( blessed $def->type )->_create_options( $rename, @paths )->@*
               : $self->_create_options( $rename, @paths, $def )->@*;
 
         }
@@ -288,7 +288,7 @@ CXC::Form::Tiny::Plugin::OptArgs2::Meta - Form metaclass role for OptArgs2
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 DESCRIPTION
 
